Function generic_div_value

pub unsafe fn generic_div_value<T, R, M, B>(
    dims: usize,
    value: T,
    a: &[T],
    result: &mut [B],
)
where T: Copy, R: SimdRegister<T>, M: Math<T>, for<'a> &'a mut [B]: WriteOnlyBuffer<Item = T>,
A generic vector division implementation over one vector and single value.

NOTE: This method DOES NOT CHEAT meaning it will not convert the value to be 1 / value and use a multiply operation, instead you must do this yourself if you wish for the ‘smarter’/faster version.

Safety

The sizes of a and result must be equal to dims, the safety requirements of M definition the basic math operations and the requirements of R SIMD register must also be followed.