Function generic_fallback_cmp_min
Source pub unsafe fn generic_fallback_cmp_min<T>(dims: usize, a: &[T]) -> T
Finds the minimum element contained within vector a of size dims returning the result.
Pseudocode
ⓘresult = inf
for i in range(dims):
result = min(result, a[i])
return result
Safety
This routine assumes:
- The sizes of a must also be equal to size dims otherwise out of
bounds access can occur.