pub unsafe fn generic_div_vector<T, R, M, B>(
dims: usize,
a: &[T],
b: &[T],
result: &mut [B],
)Expand description
A generic vector division implementation dividing by vector b.
Safety
The sizes of a, b and result must be equal to dims, the safety requirements of
M definition the basic math operations and the requirements of R SIMD register
must also be followed.